==> rc-ui-lib-0.1.35.tgz: package/es/cascader/Cascader.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

/* eslint-disable no-plusplus */
import React, { isValidElement, useContext, useEffect, useState } from 'react';
import cls from 'classnames';
import { extend } from '../utils';
import { useSetState, useUpdateEffect } from '../hooks';
import Icon from '../icon';
import Tabs from '../tabs';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var INITIAL_STATE = {
  tabs: [],
  activeTab: 0
};

var Cascader = function Cascader(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('cascader', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var _useState = useState(undefined),
      _useState2 = _slicedToArray(_useState, 2),
      internalValue = _useState2[0],
      updateInternalValue = _useState2[1];

  var _useSetState = useSetState(INITIAL_STATE),
      _useSetState2 = _slicedToArray(_useSetState, 2),
      state = _useSetState2[0],
      updateState = _useSetState2[1];

  var _extend = extend({
    text: 'text',
    value: 'value',
    children: 'children'
  }, props.fieldNames),
      textKey = _extend.text,
      valueKey = _extend.value,
      childrenKey = _extend.children;

  var getSelectedOptionsByValue = function getSelectedOptionsByValue(options, value) {
    for (var i = 0; i < options.length; i++) {
      var option = options[i];

      if (option[valueKey] === value) {
        return [option];
      }

      if (option[childrenKey]) {
        var selectedOptions = getSelectedOptionsByValue(option[childrenKey], value);

        if (selectedOptions) {
          return [option].concat(_toConsumableArray(selectedOptions));
        }
      }
    }

    return undefined;
  };

  var updateTabs = function updateTabs() {
    if (internalValue || internalValue === 0) {
      var selectedOptions = getSelectedOptionsByValue(props.options, internalValue);

      if (selectedOptions) {
        var optionsCursor = props.options;
        var tabs = selectedOptions.map(function (option) {
          var tab = {
            options: optionsCursor,
            selectedOption: option
          };
          var next = optionsCursor.find(function (item) {
            return item[valueKey] === option[valueKey];
          });

          if (next) {
            optionsCursor = next[childrenKey];
          }

          return tab;
        });

        if (optionsCursor) {
          tabs.push({
            options: optionsCursor,
            selectedOption: null
          });
        }

        updateState({
          tabs: tabs
        });
        setTimeout(function () {
          updateState({
            activeTab: tabs.length - 1
          });
        }, 0);
        return;
      }
    }

    updateState({
      tabs: [{
        options: props.options,
        selectedOption: null
      }]
    });
  };

  var onSelect = function onSelect(option, tabIndex) {
    var _props$onChange;

    if (option.disabled) {
      return;
    }

    var tabs = JSON.parse(JSON.stringify(state.tabs));
    tabs[tabIndex].selectedOption = option;

    if (tabs.length > tabIndex + 1) {
      tabs = tabs.slice(0, tabIndex + 1);
    }

    if (option[childrenKey]) {
      var nextTab = {
        options: option[childrenKey],
        selectedOption: null
      };

      if (tabs[tabIndex + 1]) {
        tabs[tabIndex + 1] = nextTab;
      } else {
        tabs.push(nextTab);
      }

      updateState({
        tabs: tabs,
        activeTab: state.activeTab + 1
      });
    }

    var selectedOptions = tabs.map(function (tab) {
      return tab.selectedOption;
    }).filter(Boolean);
    var eventParams = {
      value: option[valueKey],
      tabIndex: tabIndex,
      selectedOptions: selectedOptions
    };
    updateInternalValue(option[valueKey]);
    (_props$onChange = props.onChange) === null || _props$onChange === void 0 ? void 0 : _props$onChange.call(props, eventParams);

    if (!option[childrenKey]) {
      var _props$onFinish;

      (_props$onFinish = props.onFinish) === null || _props$onFinish === void 0 ? void 0 : _props$onFinish.call(props, eventParams);
    }
  };

  var onClose = function onClose() {
    var _props$onClose;

    return (_props$onClose = props.onClose) === null || _props$onClose === void 0 ? void 0 : _props$onClose.call(props);
  };

  var onClickTab = function onClickTab(_ref) {
    var _props$onClickTab;

    var name = _ref.name,
        title = _ref.title;
    updateState({
      activeTab: +name
    });
    (_props$onClickTab = props.onClickTab) === null || _props$onClickTab === void 0 ? void 0 : _props$onClickTab.call(props, +name, title);
  };

  var getStateFromValue = function getStateFromValue(value) {
    if (!value || !value.length) return INITIAL_STATE;

    try {
      var initialState = {
        activeTab: value.length - 1,
        tabs: []
      };
      value.reduce(function (options, v) {
        var selectedOption = options.find(function (tabs) {
          return tabs[valueKey] === v;
        });
        if (!selectedOption) throw Error('Cascader: unable to match options correctly, Please check value or defaultValue props.');
        initialState.tabs.push({
          options: options,
          selectedOption: selectedOption
        });
        return selectedOption[childrenKey];
      }, props.options);
      return initialState;
    } catch (error) {
      // eslint-disable-next-line no-console
      console.error(error);
      return INITIAL_STATE;
    }
  };

  var renderCloseIcon = function renderCloseIcon() {
    if (!props.closeable) return null;

    if (typeof props.closeIcon === 'string') {
      return /*#__PURE__*/React.createElement(Icon, {
        name: props.closeIcon,
        className: cls(bem('close-icon')),
        onClick: onClose
      });
    }

    if ( /*#__PURE__*/isValidElement(props.closeIcon)) {
      return props.closeIcon;
    }

    return null;
  };

  var renderHeader = function renderHeader() {
    return /*#__PURE__*/React.createElement("div", {
      className: cls(bem('header'))
    }, /*#__PURE__*/React.createElement("h2", {
      className: cls(bem('title'))
    }, props.title), renderCloseIcon());
  };

  var renderOption = function renderOption(option, selectedOption, tabIndex) {
    var selected = selectedOption && option[valueKey] === selectedOption[valueKey];
    var color = option.color || (selected ? props.activeColor : undefined);
    var Text = props.optionRender ? props.optionRender({
      option: option,
      selected: selected
    }) : /*#__PURE__*/React.createElement("span", null, option[textKey]);
    return /*#__PURE__*/React.createElement("li", {
      key: option[valueKey],
      className: cls(bem('option', {
        selected: selected,
        disabled: option.disabled
      }), option.className),
      style: {
        color: color
      },
      onClick: function onClick() {
        return onSelect(option, tabIndex);
      }
    }, Text, selected ? /*#__PURE__*/React.createElement(Icon, {
      name: "success",
      className: cls(bem('selected-icon'))
    }) : null);
  };

  var renderOptions = function renderOptions(options, selectedOption, tabIndex) {
    return /*#__PURE__*/React.createElement("ul", {
      key: tabIndex,
      className: cls(bem('options'))
    }, options.map(function (option) {
      return renderOption(option, selectedOption, tabIndex);
    }));
  };

  var renderTab = function renderTab(tab, tabIndex) {
    var options = tab.options,
        selectedOption = tab.selectedOption;
    var title = selectedOption ? selectedOption[textKey] : props.placeholder || '请选择';
    return /*#__PURE__*/React.createElement(Tabs.TabPane, {
      key: tabIndex,
      title: title,
      titleClass: cls(bem('tab', {
        unselected: !selectedOption
      }))
    }, renderOptions(options, selectedOption, tabIndex));
  };

  var renderTabs = function renderTabs() {
    return /*#__PURE__*/React.createElement(Tabs, {
      animated: true,
      active: state.activeTab,
      className: cls(bem('tabs')),
      color: props.activeColor,
      swipeThreshold: 0,
      swipeable: props.swipeable,
      onClickTab: onClickTab
    }, state.tabs.map(renderTab));
  };

  useEffect(function () {
    updateTabs();
  }, [JSON.stringify(props.options)]);
  useEffect(function () {
    var _props$value;

    var value = (_props$value = props.value) !== null && _props$value !== void 0 ? _props$value : props.defaultValue;
    if (!value || Array.isArray(value) && !value.length) return;
    var initialState = getStateFromValue(value);
    updateState(initialState);
  }, []);
  useUpdateEffect(function () {
    var initialState = getStateFromValue(props.value);
    updateState(initialState);
  }, [props.value]);
  useUpdateEffect(function () {
    if (internalValue || internalValue === 0) {
      var values = state.tabs.map(function (tab) {
        var _tab$selectedOption;

        return (_tab$selectedOption = tab.selectedOption) === null || _tab$selectedOption === void 0 ? void 0 : _tab$selectedOption[valueKey];
      });

      if (values.includes(internalValue)) {
        return;
      }
    }

    updateTabs();
  }, [internalValue]);
  return /*#__PURE__*/React.createElement("div", {
    className: cls(bem())
  }, renderHeader(), state.tabs.length ? renderTabs() : null);
};

Cascader.defaultProps = {
  closeable: true,
  swipeable: true,
  options: [],
  closeIcon: 'cross'
};
export default Cascader;

==> rc-ui-lib-0.2.4.tgz: package/es/cascader/Cascader.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

/* eslint-disable no-plusplus */
import React, { isValidElement, useContext, useEffect, useState } from 'react';
import classnames from 'classnames';
import { extend } from '../utils';
import { useSetState, useUpdateEffect } from '../hooks';
import Icon from '../icon';
import Tabs from '../tabs';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var INITIAL_STATE = {
  tabs: [],
  activeTab: 0
};

var Cascader = function Cascader(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('cascader', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var _useState = useState(undefined),
      _useState2 = _slicedToArray(_useState, 2),
      internalValue = _useState2[0],
      setInternalValue = _useState2[1];

  var _useSetState = useSetState(INITIAL_STATE),
      _useSetState2 = _slicedToArray(_useSetState, 2),
      state = _useSetState2[0],
      updateState = _useSetState2[1];

  var _extend = extend({
    text: 'text',
    value: 'value',
    children: 'children'
  }, props.fieldNames),
      textKey = _extend.text,
      valueKey = _extend.value,
      childrenKey = _extend.children;

  var getSelectedOptionsByValue = function getSelectedOptionsByValue(options, value) {
    for (var i = 0; i < options.length; i++) {
      var option = options[i];

      if (option[valueKey] === value) {
        return [option];
      }

      if (option[childrenKey]) {
        var selectedOptions = getSelectedOptionsByValue(option[childrenKey], value);

        if (selectedOptions) {
          return [option].concat(_toConsumableArray(selectedOptions));
        }
      }
    }

    return undefined;
  };

  var updateTabs = function updateTabs() {
    if (internalValue || internalValue === 0) {
      var selectedOptions = getSelectedOptionsByValue(props.options, internalValue);

      if (selectedOptions) {
        var optionsCursor = props.options;
        var tabs = selectedOptions.map(function (option) {
          var tab = {
            options: optionsCursor,
            selectedOption: option
          };
          var next = optionsCursor.find(function (item) {
            return item[valueKey] === option[valueKey];
          });

          if (next) {
            optionsCursor = next[childrenKey];
          }

          return tab;
        });

        if (optionsCursor) {
          tabs.push({
            options: optionsCursor,
            selectedOption: null
          });
        }

        updateState({
          tabs: tabs
        });
        setTimeout(function () {
          updateState({
            activeTab: tabs.length - 1
          });
        }, 0);
        return;
      }
    }

    updateState({
      tabs: [{
        options: props.options,
        selectedOption: null
      }]
    });
  };

  var onSelect = function onSelect(option, tabIndex) {
    var _props$onChange;

    if (option.disabled) {
      return;
    }

    var tabs = JSON.parse(JSON.stringify(state.tabs));
    tabs[tabIndex].selectedOption = option;

    if (tabs.length > tabIndex + 1) {
      tabs = tabs.slice(0, tabIndex + 1);
    }

    if (option[childrenKey]) {
      var nextTab = {
        options: option[childrenKey],
        selectedOption: null
      };

      if (tabs[tabIndex + 1]) {
        tabs[tabIndex + 1] = nextTab;
      } else {
        tabs.push(nextTab);
      }

      updateState({
        tabs: tabs,
        activeTab: state.activeTab + 1
      });
    }

    var selectedOptions = tabs.map(function (tab) {
      return tab.selectedOption;
    }).filter(Boolean);
    var eventParams = {
      value: option[valueKey],
      tabIndex: tabIndex,
      selectedOptions: selectedOptions
    };
    setInternalValue(option[valueKey]);
    (_props$onChange = props.onChange) === null || _props$onChange === void 0 ? void 0 : _props$onChange.call(props, eventParams);

    if (!option[childrenKey]) {
      var _props$onFinish;

      (_props$onFinish = props.onFinish) === null || _props$onFinish === void 0 ? void 0 : _props$onFinish.call(props, eventParams);
    }
  };

  var onClose = function onClose() {
    var _props$onClose;

    return (_props$onClose = props.onClose) === null || _props$onClose === void 0 ? void 0 : _props$onClose.call(props);
  };

  var onClickTab = function onClickTab(_ref) {
    var _props$onClickTab;

    var name = _ref.name,
        title = _ref.title;
    updateState({
      activeTab: +name
    });
    (_props$onClickTab = props.onClickTab) === null || _props$onClickTab === void 0 ? void 0 : _props$onClickTab.call(props, +name, title);
  };

  var getStateFromValue = function getStateFromValue(value) {
    if (!value || !value.length) return INITIAL_STATE;

    try {
      var initialState = {
        activeTab: value.length - 1,
        tabs: []
      };
      value.reduce(function (options, v) {
        var selectedOption = options.find(function (tabs) {
          return tabs[valueKey] === v;
        });

        if (!selectedOption) {
          throw Error('Cascader: unable to match options correctly, Please check value or defaultValue props.');
        }

        initialState.tabs.push({
          options: options,
          selectedOption: selectedOption
        });
        return selectedOption[childrenKey];
      }, props.options);
      return initialState;
    } catch (error) {
      // eslint-disable-next-line no-console
      console.error(error);
      return INITIAL_STATE;
    }
  };

  var renderCloseIcon = function renderCloseIcon() {
    if (!props.closeable) return null;

    if (typeof props.closeIcon === 'string') {
      return /*#__PURE__*/React.createElement(Icon, {
        name: props.closeIcon,
        className: classnames(bem('close-icon')),
        onClick: onClose
      });
    }

    if ( /*#__PURE__*/isValidElement(props.closeIcon)) {
      return props.closeIcon;
    }

    return null;
  };

  var renderHeader = function renderHeader() {
    return /*#__PURE__*/React.createElement("div", {
      className: classnames(bem('header'))
    }, /*#__PURE__*/React.createElement("h2", {
      className: classnames(bem('title'))
    }, props.title), renderCloseIcon());
  };

  var renderOption = function renderOption(option, selectedOption, tabIndex) {
    var selected = selectedOption && option[valueKey] === selectedOption[valueKey];
    var color = option.color || (selected ? props.activeColor : undefined);
    var Text = props.optionRender ? props.optionRender({
      option: option,
      selected: selected
    }) : /*#__PURE__*/React.createElement("span", null, option[textKey]);
    return /*#__PURE__*/React.createElement("li", {
      key: option[valueKey],
      className: classnames(bem('option', {
        selected: selected,
        disabled: option.disabled
      }), option.className),
      style: {
        color: color
      },
      onClick: function onClick() {
        return onSelect(option, tabIndex);
      }
    }, Text, selected ? /*#__PURE__*/React.createElement(Icon, {
      name: "success",
      className: classnames(bem('selected-icon'))
    }) : null);
  };

  var renderOptions = function renderOptions(options, selectedOption, tabIndex) {
    return /*#__PURE__*/React.createElement("ul", {
      key: tabIndex,
      className: classnames(bem('options'))
    }, options.map(function (option) {
      return renderOption(option, selectedOption, tabIndex);
    }));
  };

  var renderTab = function renderTab(tab, tabIndex) {
    var options = tab.options,
        selectedOption = tab.selectedOption;
    var title = selectedOption ? selectedOption[textKey] : props.placeholder || '请选择';
    return /*#__PURE__*/React.createElement(Tabs.TabPane, {
      key: tabIndex,
      title: title,
      titleClass: classnames(bem('tab', {
        unselected: !selectedOption
      }))
    }, renderOptions(options, selectedOption, tabIndex));
  };

  var renderTabs = function renderTabs() {
    return /*#__PURE__*/React.createElement(Tabs, {
      animated: true,
      active: state.activeTab,
      className: classnames(bem('tabs')),
      color: props.activeColor,
      swipeThreshold: 0,
      swipeable: props.swipeable,
      onClickTab: onClickTab
    }, state.tabs.map(renderTab));
  };

  useEffect(function () {
    updateTabs();
  }, [JSON.stringify(props.options)]);
  useEffect(function () {
    var _props$value;

    var value = (_props$value = props.value) !== null && _props$value !== void 0 ? _props$value : props.defaultValue;
    if (!value || Array.isArray(value) && !value.length) return;
    var initialState = getStateFromValue(value);
    updateState(initialState);
  }, []);
  useUpdateEffect(function () {
    var initialState = getStateFromValue(props.value);
    updateState(initialState);
  }, [props.value]);
  useUpdateEffect(function () {
    if (internalValue || internalValue === 0) {
      var values = state.tabs.map(function (tab) {
        var _tab$selectedOption;

        return (_tab$selectedOption = tab.selectedOption) === null || _tab$selectedOption === void 0 ? void 0 : _tab$selectedOption[valueKey];
      });

      if (values.includes(internalValue)) {
        return;
      }
    }

    updateTabs();
  }, [internalValue]);
  return /*#__PURE__*/React.createElement("div", {
    className: classnames(bem())
  }, renderHeader(), state.tabs.length ? renderTabs() : null);
};

Cascader.defaultProps = {
  closeable: true,
  swipeable: true,
  options: [],
  closeIcon: 'cross'
};
export default Cascader;
